@@ -15,13 +15,6 @@ Example:
             return {"message": "Hello from FastApps!"}
 """
 
-# Get version from package metadata
-try:
-    from importlib.metadata import version
-    __version__ = version("fastapps")
-except Exception:
-    __version__ = "1.2.0"  # Fallback version
-
 __author__ = "FastApps Team"
 
 from .builder.compiler import WidgetBuilder, WidgetBuildResult
@@ -56,4 +49,13 @@ __all__ = [
     "WidgetBuildResult",
     "Field",
     "ConfigDict",
+    # Dev server API
+    "start_dev_server",
+    "start_dev_server_with_config",
+    "get_server_info",
+    "run_dev_server",
+    "DevServerConfig",
+    "ServerInfo",
+    "DevServerError",
+    "ProjectNotFoundError",
 ] + _auth_exports
