@@ -5,12 +5,12 @@ Provides built-in JWT verification, per-widget auth decorators,
 and re-exports FastMCP auth components.
 """
 
-from .verifier import JWTVerifier
 from .decorators import auth_required, no_auth, optional_auth
+from .verifier import JWTVerifier
 
 # Re-export FastMCP auth components for convenience
 try:
-    from mcp.server.auth.provider import TokenVerifier, AccessToken
+    from mcp.server.auth.provider import AccessToken, TokenVerifier
 except ImportError:
     # Graceful fallback if fastmcp version doesn't have auth
     TokenVerifier = None
@@ -24,4 +24,3 @@ __all__ = [
     "no_auth",
     "optional_auth",
 ]
-
