@@ -3,6 +3,10 @@
 import click
 from rich.console import Console
 
+from fastapps.core.utils import get_cli_version
+
+from .commands.build import build_command
+from .commands.cloud import cloud
 from .commands.create import create_widget
 from .commands.dev import start_dev_server
 from .commands.init import init_project
@@ -10,16 +14,9 @@ from .commands.use import use_integration
 
 console = Console()
 
-# Get version from package metadata
-try:
-    from importlib.metadata import version
-    __version__ = version("fastapps")
-except Exception:
-    __version__ = "unknown"
-
 
 @click.group()
-@click.version_option(version=__version__, prog_name="fastapps")
+@click.version_option(version=get_cli_version(), prog_name="fastapps")
 def cli():
     """FastApps - ChatGPT Widget Framework
 
@@ -118,10 +115,12 @@ def dev(port, host):
 @cli.command()
 def build():
     """Build widgets for production."""
-    console.print("[green]Building widgets...[/green]")
-    console.print("[yellow]This feature will be implemented in Phase 4[/yellow]")
-    console.print("\n[cyan]For now, use:[/cyan]")
-    console.print("  npm run build")
+    build_command()
+
+
+# Register cloud command group
+cli.add_command(cloud)
+
 
 @cli.command()
 def auth_info():
@@ -163,10 +162,6 @@ def auth_info():
     console.print("  [dim]async def execute(self, input_data, context, user):[/dim]")
     console.print("  [dim]    if user.is_authenticated:[/dim]")
     console.print("  [dim]        return {'user_id': user.subject}[/dim]")
-
-    console.print("\n[cyan]Documentation:[/cyan]")
-    console.print("  Server auth: docs/08-AUTH.md")
-    console.print("  Per-widget auth: docs/09-PER-WIDGET-AUTH.md")
     console.print()
 
 
