@@ -1,5 +1,5 @@
 """Type exports for Flick framework."""
 
-from pydantic import Field, ConfigDict
+from pydantic import ConfigDict, Field
 
 __all__ = ["Field", "ConfigDict"]
